export default {
    state: {
        homeMenu: {
            isVisible: false,
            itens: [
                {
                    name: 'Perfil',
                    icon: 'fas fa-user',
                    action: '/profile'
                },
                {
                    name: 'Alterar Senha',
                    icon: 'fas fa-key',
                    action: '/updatePassword'
                },
                {
                    name: 'Recarregar Cartão',
                    icon: 'fas fa-refresh',
                    action: '/cardRecharge'
                },
                {
                    name: 'Fale Conosco',
                    icon: 'fa-solid fa-headset',
                    action: '/contactUs'
                },
                {
                    name: 'Precisa de ajuda?',
                    icon: 'fa-solid fa-question',
                    action: '/help',
                    external: true
                }
            ],
            footerItens: [
                {
                    name: 'Sair',
                    icon: 'fa-solid fa-sign-out',
                    action: 'logOut'
                }
            ]
        },
        login: {
            controlsEnabled: true,
            isLoading: false,
            formData: [
                {
                    display: 'Escolha a instituição',
                    required: true,
                    isVisible: process.env.usa_instituicao_cliente_filial === 'N',
                    type: 'select'
                },
                {
                    placeHolder: 'Digite seu login',
                    display: 'Login (CPF, Matrícula, Nome de usuário)',
                    required: true,
                    type: 'text',
                    isVisible: true
                },
                {
                    placeHolder: 'Digite sua senha',
                    display: 'Senha',
                    required: true,
                    type: 'password',
                    isVisible: true
                },
                {
                    display: 'Lembrar senha',
                    type: 'checkbox',
                    isVisible: true
                }
            ],
            buttons: [
                {
                    display: 'Entrar',
                    fill: true,
                    action: 'login',
                    show: true
                },
                {
                    icon: 'key',
                    display: 'Esqueci minha senha',
                    action: 'changeRecoverPasswordMenuVisibility',
                    show: true
                },
                {
                    display: 'Cadastrar',
                    action: 'register',
                    show: false
                },
                {
                    display: 'Precisa de ajuda?',
                    action: 'help',
                    show: true
                }
            ]
        },
        menuList: [
            {
                icon: 'fa-regular fa-money-bill',
                display: 'Saldo',
                visControl: null,
                action: '/fullBalance'
            },
            {
                icon: 'fas fa-credit-card',
                display: 'Recarregar Saldo',
                visControl: 'RECARREGACARTAO',
                action: '/cardRecharge'
            },
            {
                icon: 'fas fa-address-card',
                display: 'Meus Cartões',
                visControl: null,
                action: '/myCards'
            },
            {
                icon: 'fa-solid fa-headset',
                display: 'Fale Conosco',
                visControl: null,
                action: '/contactUs'
            },
            {
                icon: 'fa-solid fa-utensils',
                display: 'Cardapio',
                visControl: 'VISUALIZACARDAPIO',
                action: '/menu'
            }
        ],
        recoverPasswordMenu: {
            isVisible: false
        },
        recoverPasswordFormData: [
            {
                display: 'Escolha uma instituição',
                required: true,
                isVisible: process.env.usa_instituicao_cliente_filial === 'N',
                type: 'select',
                value: null
            }
        ],
        modalInfo: {
            isVisible: false,
            text: '',
            icon: '',
            buttons: [],
            types: {
                default: {
                    icon: 'fa-solid fa-check',
                    buttons: [
                        {
                            buttonText: 'Fechar',
                            buttonAction: 'closeModal'
                        }
                    ]
                },
                success: {
                    icon: 'fa-solid fa-check',
                    buttons: [
                        {
                            buttonText: 'Fechar',
                            buttonAction: 'closeModal'
                        }
                    ]
                },
                defaultDialog: {
                    icon: 'fa-solid fa-question',
                    buttons: [
                        {
                            buttonText: 'Sim',
                            buttonAction: 'actionTrue'
                        },
                        {
                            buttonText: 'Não',
                            buttonAction: 'actionFalse'
                        }
                    ]
                },
                error: {
                    icon: 'fa-solid fa-warning',
                    buttons: [
                        {
                            buttonText: 'Fechar',
                            buttonAction: ''
                        }
                    ]
                }
            }
        },
        selectList: {
            isVisible: false,
            title: '',
            optionDisplay: '',
            options: [],
            event: ''
        },
        deleteItemMenu: {
            isVisible: false
        },
        baseInfo: {
            CDCLIENTE: '',
            CDFILIAL: '',
            NMFANTCLIE: ''
        },
        isOnline: true,
        baseInfoList: []
    },
    mutations: {
        setHomeMenuVisibility (state) {
            state.homeMenu.isVisible = !state.homeMenu.isVisible
        },
        setRecoverPasswordMenuVisibility (state) {
            state.recoverPasswordMenu.isVisible = !state.recoverPasswordMenu.isVisible
        },
        showModalInfo (state, data) {
            const type = data.type || 'default'
            state.modalInfo.text = data.text
            state.modalInfo.icon = data.icon || state.modalInfo.types[type].icon
            state.modalInfo.buttons = data.buttons || state.modalInfo.types[type].buttons

            if (data.open) {
                state.modalInfo.isVisible = true
            }
        },
        closeModalInfo (state) {
            state.modalInfo.isVisible = false
        },
        showSelectList (state, data) {
            state.selectList.title = data.title
            state.selectList.options = data.options
            state.selectList.optionDisplay = data.optionDisplay
            state.selectList.event = data.event
            state.selectList.isVisible = true
        },
        closeSelectList (state) {
            state.selectList.title = ''
            state.selectList.options = []
            state.selectList.optionDisplay = ''
            state.selectList.event = ''
            state.selectList.isVisible = false
        },
        setDeleteItemMenuVisibility (state) {
            state.deleteItemMenu.isVisible = !state.deleteItemMenu.isVisible
        },
        setBaseInfo (state, data) {
            state.baseInfo.CDCLIENTE = data.CDCLIENTE
            state.baseInfo.CDFILIAL = data.CDFILIAL
            state.baseInfo.NMFANTCLIE = data.NMFANTCLIE
        },
        setBaseInfoList (state, data) {
            state.baseInfoList = data
        },
        setLoginControlsEnabled (state, data) {
            state.login.controlsEnabled = data
        },
        resetLoginState (state) {
            state.login.formData[0].value = null
            state.login.formData[1].value = null
            state.login.formData[2].value = null
            state.login.formData[3].value = true
        },
        setShowRegisterButton (state, data) {
            state.login.buttons[2].show = data
        },
        setOnlineStatus (state, data) {
            state.isOnline = data
        },
        startLoadingLogin (state) {
            state.login.isLoading = true
        },
        stopLoadingLogin (state) {
            state.login.isLoading = false
        },
        resetRecoverPasswordFormData (state) {
            state.recoverPasswordFormData[0].value = null
        }
    },
    actions: {
        changeHomeMenuVisibility ({ commit }) {
            commit('setHomeMenuVisibility')
        },
        changeRecoverPasswordMenuVisibility ({ commit }) {
            commit('setRecoverPasswordMenuVisibility')
        },
        showModalInfo ({ commit }, data) {
            commit('showModalInfo', data)
        },
        closeModalInfo ({ commit }) {
            commit('closeModalInfo')
        },
        showSelectList ({ commit }, data) {
            commit('showSelectList', data)
        },
        closeSelectList ({ commit }) {
            commit('closeSelectList')
        },
        changeDeleteItemVisibility ({ commit }) {
            commit('setDeleteItemMenuVisibility')
        },
        setBaseInfo ({ commit }, data) {
            commit('setBaseInfo', data)
        },
        setBaseInfoList ({ commit }, data) {
            commit('setBaseInfoList', data)
        },
        setLoginControlsEnabled ({ commit }, data) {
            commit('setLoginControlsEnabled', data)
        },
        resetLoginState ({ commit }) {
            commit('resetLoginState')
        },
        setShowRegisterButton ({ commit }, data) {
            commit('setShowRegisterButton', data)
        },
        setOnlineStatus ({ commit }, data) {
            commit('setOnlineStatus', data)
        },
        startLoadingLogin ({ commit }) {
            commit('startLoadingLogin')
        },
        stopLoadingLogin ({ commit }) {
            commit('stopLoadingLogin')
        },
        resetRecoverPasswordFormData ({ commit }) {
            commit('resetRecoverPasswordFormData')
        }
    },
    getters: {
        homeMenuList: (state) => state.menuList,
        homeMenu: (state) => state.homeMenu,
        recoverPasswordMenu: (state) => state.recoverPasswordMenu,
        modalInfo: (state) => state.modalInfo,
        selectList: (state) => state.selectList,
        deleteItemMenu: (state) => state.deleteItemMenu,
        getBaseInfo: (state) => state.baseInfo,
        getBaseInfoList: (state) => state.baseInfoList,
        getLoginFormData: (state) => state.login.formData,
        getRecoverPasswordFormData: (state) => state.recoverPasswordFormData,
        getLoginButtons: (state) => state.login.buttons,
        loginControlsEnabled: (state) => state.login.controlsEnabled,
        getOnlineStatus: (state) => state.isOnline,
        loginIsLoading: (state) => state.login.isLoading
    }
}
